Learn R Programming

AnthropMMD (version 0.9.9)

AnthropMMD-package: A GUI for Mean Measures of Divergence

Description

Offers a complete and interactive GUI to work out a matrix of Mean Measures of Divergence from a binary dataset, especially for anthropologists.

Arguments

Details

ll{ Package: AnthropMMD Type: Package Version: 0.9.9 Date: 2014-04-18 License: GPL (>= 2) }

References

Sjovold, T. (1977). Non-metrical Divergence Between Skeletal Populations. Ossa, 4, Supp. 1.

Harris, E. F., Sjovold, T. (2004). Calculation of Smith's Mean Measure of Divergence for Intergroup Comparisons Using Nonmetric Data. Dental Anthropology, 17(3), 83-93.

Examples

Run this code
StartMMD() # the only command to know : simply type it to begin !

Run the code above in your browser using DataLab