Learn R Programming

AnthropMMD (version 0.9.5)

datafile_details: Internal function : tcltk code to display a window asking for details about the layout of the data file.

Description

tcltk code for a windows asking if the data file contains raw binary data (standard case), or is a summarized matrix containing the number of individual and the proportion of presence for eacch variable and each group.

Usage

datafile_details()

Arguments

Value

  • A character vector indicating the choice made by the user.